#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-web
version:              1.52.1
visibility:           public
id:                   hledger-web-1.52.1-9PoC16IDkKMAPnDkdp1xfl
key:                  hledger-web-1.52.1-9PoC16IDkKMAPnDkdp1xfl
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Web user interface for the hledger accounting system
description:
    A simple web user interface for the hledger accounting system,
    providing a more modern UI than the command-line or terminal interfaces.
    It can be used as a local single-user UI, or as a multi-user UI for
    viewing\/adding\/editing on the web.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance
abi:                  5809eef52f455c9b2cd13ed140157fc1
exposed:              True
exposed-modules:
    Hledger.Web Hledger.Web.App Hledger.Web.Application
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Main Hledger.Web.Settings
    Hledger.Web.Settings.StaticFiles Hledger.Web.Test
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common

hidden-modules:       Paths_hledger_web
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-web
hs-libraries:         HShledger-web-1.52.1-9PoC16IDkKMAPnDkdp1xfl
depends:
    Decimal-0.5.2-EO2ogRu16NZGZrbjdz8WSo
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT base-4.18.2.1
    base64-1.0-IoB6JaxRPmN6BuW56w5zb9
    blaze-html-0.9.2.0-3zJbEruN1MK4AfSPvaGc85
    blaze-markup-0.8.3.0-DDuKg87sJ0pLWg6HCDFYiH bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    clientsession-0.9.3.0-Jt6h86nD0VJHqqUq9lz2i5
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-Cq9iqjolcw6I0oNouBZzAG
    conduit-extra-1.3.8-9gSM61pV2WFG1rnKdBHlFQ containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-5TJRL61mQdJ37nJ79jr8U
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    githash-0.1.7.0-961G3VId53S1j2pOyAlOQT
    hjsmin-0.2.1-KIRAyDR76fj1B6IkQRInOJ
    hledger-1.52.1-1oVgsvUwobmHQXssiAKHNH
    hledger-lib-1.52.1-A6hExq7BFm5Hu1YUbbOSub
    hspec-2.11.7-1kXgaDR9lLG3Aajebanad0
    http-client-0.7.19-3CnIhmcn0K76iPGUX0cQMN
    http-conduit-2.3.9.1-DP2lFgSMOheFQZhXqyYPv7
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    megaparsec-9.7.0-HRxDu6YnAVL4jvPx7zVygA mtl-2.3.1
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    safe-0.3.21-Ki9XWKg9cP9KpwzlIW2n9t
    shakespeare-2.1.7.1-CYfmcl5gLtO2fbZxPknygS
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-5qyX2ayBMsxIkyKkm0rJa5
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    wai-3.2.4-JKCq5JcGzi0CtrYAeT794h
    wai-cors-0.2.7-7blYc3Zy46HJ9aAe3Ais5o
    wai-extra-3.1.18-65hUHH1RffHL4BiigvOOLm
    wai-handler-launch-3.0.3.1-CqqAX8ZCkxh6jElXXchZyi
    warp-3.4.0-46pmJiGox9pGiGB1xG7SW0
    yaml-0.11.11.2-GPR6m7oANO4BJZ4x5NErMN
    yesod-1.6.2.1-sajPUNrKeM1e81dExDw4W
    yesod-core-1.6.28.0-9BWXtxFdbtOCZ6GV3RO8n7
    yesod-form-1.7.9.3-INHspjvD6oC5wRVT4Gvk5f
    yesod-static-1.6.1.2-4BD9EuczLpFAdbTJhJpMap
    yesod-test-1.6.23-JGeDaBVWgrJIdLROdWj4S3

haddock-interfaces:   /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html:         /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

